@@ -5,7 +5,7 @@
 #include "config.h"
 #include "meta.h"
 
-#define ACVERSION "0.1.9"
+#define ACVERSION "0.2.1"
 
 class hostdata;
 
@@ -13,14 +13,14 @@ namespace acfg
 {
 
 extern MYSTD::string cachedir, logdir, confdir, fifopath, user, group, pidfile, 
-reportpage, ifilepat, pfilepat, agentname, remoteport;
+reportpage, vfilepat, pfilepat, agentname, remoteport, adminauth, bindaddr, port;
 
-extern int port, debug, offlinemode, foreground, verbose, stupidfs, forcemanaged, 
-expdelay, verboselog, extreshhold, tpoolsize, dnscachetime, dlbufsize;
+extern int debug, offlinemode, foreground, verbose, stupidfs, forcemanaged, 
+verboselog, extreshhold, tpoolsize, dnscachetime, dlbufsize;
 
 extern tHttpUrl proxy_info;
 
-void SetOption(const MYSTD::string &key, const MYSTD::string &value);
+bool SetOption(const MYSTD::string &line, bool bQuiet=false);
 void ReadConfigDirectory(const char*);
 
 //! Prepare various things resulting from variable combinations, etc.
