@@ -13,20 +13,23 @@
 
 class dlcon;
 class job;
+class header;
 
 class con;
 typedef SHARED_PTR<con> tConPtr;
 
-class con : public condition {
+class con {
    public: 
       con(int fdId, const char *client);
       ~con();
       
       void WorkLoop();
-      void HelpLoop();
+      //void HelpLoop();
+#ifdef KILLABLE
       //! Tell running threads to stop
       void SignalStop();
-      //! Terminate the connection gracefully
+#endif
+      //! Terminate the connection descriptors gracefully
       void ShutDown();
       
    private:
@@ -35,10 +38,12 @@ class con : public condition {
 
       int m_confd;
       
-      MYSTD::list<job*> m_jobs2prep, m_jobs2send;
+      MYSTD::list<job*> m_jobs2send;
       
+#ifdef KILLABLE
       // to awake select with dummy data
       int wakepipe[2];
+#endif
       
       bool m_bStopActivity;
       
@@ -49,7 +54,14 @@ class con : public condition {
       bool SetupDownloader();
       dlcon * m_pDlClient;
       rechecks rex;
-      MYSTD::string m_sClientHost;          
+      MYSTD::string m_sClientHost;
+      header *m_pTmpHead;
+      
+      MYSTD::string m_sLastFile;
+      off_t m_nLastIn, m_nLastOut;
+      void HandleStats(job*);
+      void WriteAndDropStats();
+
 };
 
 #endif
