@@ -20,7 +20,7 @@ public:
 	// FileHandler
 	virtual void ProcessRegular(const MYSTD::string &sPath, const struct stat &);
 	virtual void ProcessOthers(const MYSTD::string &sPath, const struct stat &);
-	tStrVec m_indexFiles;
+	tStrVec m_volatileFiles;
 
 protected:
 
@@ -28,21 +28,24 @@ protected:
 	virtual void SendMsg(const MYSTD::string &x);
 	void DumpLog(time_t id);
 	
-	void _UpdateIfiles();
+	void _UpdateVolatileFiles();
 	void _BusyDisplayLogs();
 	void _Usermsg(MYSTD::string m);
 	virtual void _HandlePkgEntry(const MYSTD::string & refererPath, const NoCaseStringMap &info);
-	void _ParseIfilesAndHandleEntries();
+	void _ParseVolatileFilesAndHandleEntries();
 
 	
 	// File handler
 	time_t now;
 	tStrPos nDropPrefLen;
 	rechecks rex;
+	
+	int m_nErrorCount;
 
 private:
 	
-	typedef MYSTD::map<MYSTD::string,MYSTD::pair<time_t,MYSTD::string> > trashmap_t; // local path name, time when the file became unreferenced, path to it
+	// local path name, time when the file became unreferenced, path to it
+	typedef MYSTD::map<MYSTD::string,MYSTD::pair<time_t,MYSTD::string> > trashmap_t;
 	trashmap_t m_trash;
 	
 	// t.h. with trees&Co., this is fast enough
@@ -54,6 +57,8 @@ private:
 	
 	FILE *m_repFileStream;
 
+	expiration(const expiration&);
+	expiration& operator=(const expiration&);
 };
 
 
