@@ -13,6 +13,8 @@ public:
 	/// This method controls header/footer printing and termination
 	/// Override only when really needed! Instead, use Action for contents of regular pages! 
 	virtual void Run(const MYSTD::string &cmd)=0;
+
+	bool m_bErrAbort;
 	
 protected:
 	
@@ -26,6 +28,9 @@ protected:
 	void SetStyle(MYSTD::string&);
 	int m_reportFD;
 	const char *m_szDecoFile;
+private:
+	maintenance(const maintenance&);
+	maintenance& operator=(const maintenance&);
 };
 
 class reportgen : public maintenance
@@ -36,6 +41,6 @@ public:
 	virtual void GenReport();
 };
 
-void DispatchAndRunMaintTask(const MYSTD::string &, int);
+void DispatchAndRunMaintTask(const MYSTD::string &, int, const char*);
 
 #endif /*MAINTENANCE_H_*/
