@@ -70,9 +70,9 @@ struct ltstr
 typedef MYSTD::map<MYSTD::string, MYSTD::string, ltstring> NoCaseStringMap;
 typedef MYSTD::map<MYSTD::string, MYSTD::string> tStringMap;
 
-inline void trimFront(MYSTD::string &s)
+inline void trimFront(MYSTD::string &s, const char *junk=SPACECHARS)
 {
-	MYSTD::string::size_type pos = s.find_first_not_of(SPACECHARS);
+	MYSTD::string::size_type pos = s.find_first_not_of(junk);
 	if(pos != 0)
 		s.erase(0, pos);
 }
@@ -83,6 +83,12 @@ inline void trimBack(MYSTD::string &s, const char *junk=SPACECHARS)
 	s.erase(pos+1);
 }
 
+inline void trimString(MYSTD::string &s, const char *junk=SPACECHARS)
+{
+	trimBack(s, junk);
+	trimFront(s, junk);
+}
+
 //MYSTD::string sbasename(const char *in);
 
 void trimProto(MYSTD::string & sUri);
@@ -126,7 +132,6 @@ bool _ParseLine(const MYSTD::string & sIn, MYSTD::string & sOutKey, MYSTD::strin
 
 class tHttpUrl {
 public:
-	//tHttpUrl();
 	bool SetHttpUrl(MYSTD::string uri);
 	/*
 	/// The specified url has a path which is a prefix of the one in *this 
@@ -137,6 +142,15 @@ public:
 	//void *pMisc;
 };
 
+#define POKE(x) while( write(x, "", 1) <0);
+
+typedef struct { const char *name; MYSTD::string *ptr; } MapNameToString;
+typedef struct { const char *name; int *ptr; } MapNameToInt;
+
+void appendLong(MYSTD::string &s, long val);
+
+#define OFFT_MAX (std::numeric_limits<off_t>::max())
 
 #endif
 
+
