@@ -50,7 +50,7 @@ void transfer(bool bDirIn, uint64_t nCount, const char *szClient, const char *sz
 			(unsigned long) time(NULL), bDirIn ? 'I' : 'O', nCount,
 					szClient, szPath);
 
-	if(acfg::debug || acfg::verbose)
+	if(acfg::debug>3)
 		fflush(fStat);
 }
 
@@ -81,8 +81,8 @@ void err(const char *msg, const char *client)
 		fprintf(stderr, "%s|%s\n", buf, msg);
 		fflush(stderr);
 	}
-	fflush(fErr);
 #endif
+	fflush(fErr);
 	
 }
 
@@ -95,12 +95,30 @@ void flush()
 		fflush(fStat);
 }
 
+void reopen()
+{
+	lockguard g(&mx);
+	if (fErr)
+		fclose(fErr);
+	if (fStat)
+		fclose(fStat);
+	aclog::open();
+}
+
 void close()
 {
 	lockguard g(&mx);
-	if(acfg::verbose || acfg::debug) cerr << "Closing logs...\n";
-	if(fErr) fclose(fErr);
-	if(fStat) fclose(fStat);
+	if(acfg::debug>4) cerr << "Closing logs...\n";
+	if(fErr) 
+	{
+		fclose(fErr);
+		fErr=NULL;
+	}
+	if(fStat) 
+	{
+		fclose(fStat);
+		fStat=NULL;
+	}
 }
 
 typedef struct {
