@@ -49,9 +49,7 @@ void showinfo::Run(const string &)
 		string contents(pagebuf.rptr(), pagebuf.size());
 		SetStyle(contents);
 		StrSubst(contents, "$SERVERIP", GetHostname());
-		char buf[10];
-		sprintf(buf, "%d", acfg::port);
-		StrSubst(contents, "$SERVERPORT", buf);
+		StrSubst(contents, "$SERVERPORT", acfg::port.c_str());
 		StrSubst(contents, "$REPAGE", sPathSepUnix+acfg::reportpage);
 		
 		SendMsg(contents);
